@@ -6,7 +6,7 @@
     <message>
         <location filename="../colorLabel.cpp" line="37"/>
         <source>Click to change color</source>
-        <translation>Щракни за смяна на цвета</translation>
+        <translation>Щракнете за смяна на цвета</translation>
     </message>
     <message>
         <location filename="../colorLabel.cpp" line="61"/>
@@ -239,7 +239,7 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
         <translation>(Потребителска тема)</translation>
     </message>
     <message>
-        <location filename="../lxqtthemeconfig.cpp" line="185"/>
+        <location filename="../lxqtthemeconfig.cpp" line="188"/>
         <source>Open theme folder</source>
         <translation>Отваряне на папката с темата</translation>
     </message>
