@@ -34,7 +34,7 @@
     <message>
         <location filename="../configothertoolkits.cpp" line="244"/>
         <source>Error: gsettings cannot be run</source>
-        <translation type="unfinished"></translation>
+        <translation>Error: gsettings cannot be run</translation>
     </message>
 </context>
 <context>
@@ -237,7 +237,7 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lxqtthemeconfig.cpp" line="185"/>
+        <location filename="../lxqtthemeconfig.cpp" line="188"/>
         <source>Open theme folder</source>
         <translation type="unfinished"></translation>
     </message>
@@ -314,7 +314,7 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     <message>
         <location filename="../styleconfig.ui" line="77"/>
         <source>Some Qt styles may ignore these colors.</source>
-        <translation type="unfinished"></translation>
+        <translation>Some Qt styles may ignore these colours.</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="102"/>
