@@ -198,7 +198,7 @@ Uvjeri se da je „xsettingsd” instaliran, koji GTK programima pomaže trenutn
     <message>
         <location filename="../iconthemeconfig.ui" line="14"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>LXQt konfiguracija izgleda</translation>
+        <translation>Konfiguracija LXQt izgleda</translation>
     </message>
     <message>
         <location filename="../iconthemeconfig.ui" line="26"/>
@@ -231,7 +231,7 @@ Uvjeri se da je „xsettingsd” instaliran, koji GTK programima pomaže trenutn
     <message>
         <location filename="../lxqtthemeconfig.ui" line="64"/>
         <source>Use palette provided by theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Koristi paletu koju pruža tema</translation>
     </message>
     <message>
         <location filename="../lxqtthemeconfig.cpp" line="83"/>
@@ -239,7 +239,7 @@ Uvjeri se da je „xsettingsd” instaliran, koji GTK programima pomaže trenutn
         <translation>(Korisnička tema)</translation>
     </message>
     <message>
-        <location filename="../lxqtthemeconfig.cpp" line="185"/>
+        <location filename="../lxqtthemeconfig.cpp" line="188"/>
         <source>Open theme folder</source>
         <translation>Otvori mapu tema</translation>
     </message>
@@ -268,7 +268,7 @@ Uvjeri se da je „xsettingsd” instaliran, koji GTK programima pomaže trenutn
     <message>
         <location filename="../main.cpp" line="61"/>
         <source>LXQt Appearance Configuration</source>
-        <translation>LXQt konfiguracija izgleda</translation>
+        <translation>Konfiguracija LXQt izgleda</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="74"/>
@@ -336,7 +336,7 @@ Uvjeri se da je „xsettingsd” instaliran, koji GTK programima pomaže trenutn
     <message>
         <location filename="../styleconfig.ui" line="132"/>
         <source>Tooltip:</source>
-        <translation type="unfinished"></translation>
+        <translation>Opis alata:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="146"/>
@@ -361,7 +361,7 @@ Uvjeri se da je „xsettingsd” instaliran, koji GTK programima pomaže trenutn
     <message>
         <location filename="../styleconfig.ui" line="196"/>
         <source>Tooltip Text:</source>
-        <translation type="unfinished"></translation>
+        <translation>Tekst opisa alata:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="210"/>
@@ -390,7 +390,7 @@ Uvjeri se da je „xsettingsd” instaliran, koji GTK programima pomaže trenutn
         <location filename="../styleconfig.ui" line="336"/>
         <location filename="../styleconfig.ui" line="368"/>
         <source>May be overridden by Qt style or app</source>
-        <translation type="unfinished"></translation>
+        <translation>Može se nadjačati Qt stilom ili aplikacijom</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="287"/>
@@ -425,32 +425,32 @@ Uvjeri se da je „xsettingsd” instaliran, koji GTK programima pomaže trenutn
     <message>
         <location filename="../styleconfig.ui" line="329"/>
         <source>Toolbar icon size:</source>
-        <translation type="unfinished"></translation>
+        <translation>Veličina ikone alatne trake:</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="340"/>
         <source>16</source>
-        <translation type="unfinished"></translation>
+        <translation>16</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="345"/>
         <source>22</source>
-        <translation type="unfinished"></translation>
+        <translation>22</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="350"/>
         <source>24</source>
-        <translation type="unfinished"></translation>
+        <translation>24</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="355"/>
         <source>32</source>
-        <translation type="unfinished"></translation>
+        <translation>32</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="360"/>
         <source>48</source>
-        <translation type="unfinished"></translation>
+        <translation>48</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="371"/>
