@@ -160,7 +160,7 @@
     <message>
         <location filename="../mouseconfig.ui" line="64"/>
         <source>Left handed (Swap left and right mouse buttons)</source>
-        <translation>Лява ръка (смяна на ляв и десен бутони на мишката)</translation>
+        <translation>За лява ръка (смяна на ляв и десен бутони на мишката)</translation>
     </message>
     <message>
         <location filename="../mouseconfig.ui" line="57"/>
@@ -176,7 +176,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="39"/>
+        <location filename="../lxqt-config-input.cpp" line="41"/>
         <source>LXQt input settings are currently unsupported under Wayland.
 
 Mouse, touchpad and keyboard can be configured in the settings of the compositor.</source>
@@ -185,37 +185,37 @@ Mouse, touchpad and keyboard can be configured in the settings of the compositor
 Мишката, тъчпадът и клавиатурата могат да бъдат конфигурирани в настройките на композитора.</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="76"/>
+        <location filename="../lxqt-config-input.cpp" line="78"/>
         <source>Keyboard and Mouse Settings</source>
         <translation>Настройки на клавиатурата и мишката</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="94"/>
+        <location filename="../lxqt-config-input.cpp" line="96"/>
         <source>Mouse</source>
         <translation>Мишка</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="103"/>
+        <location filename="../lxqt-config-input.cpp" line="105"/>
         <source>Cursor</source>
         <translation>Курсор</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="108"/>
+        <location filename="../lxqt-config-input.cpp" line="110"/>
         <source>To apply the changes also to GTK, check LXQt Appearance Configuration → GTK Style.</source>
         <translation>За да приложите промените и към GTK, изберете Конфигурация на външния вид на LXQt → GTK Стил.</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="112"/>
+        <location filename="../lxqt-config-input.cpp" line="114"/>
         <source>Keyboard</source>
         <translation>Клавиатура</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="123"/>
+        <location filename="../lxqt-config-input.cpp" line="125"/>
         <source>Keyboard Layout</source>
         <translation>Клавиатурна подредба</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="136"/>
+        <location filename="../lxqt-config-input.cpp" line="138"/>
         <source>Mouse and Touchpad</source>
         <translation>Мишка и тъчпад</translation>
     </message>
@@ -253,12 +253,12 @@ Mouse, touchpad and keyboard can be configured in the settings of the compositor
     <message>
         <location filename="../touchpadconfig.ui" line="37"/>
         <source>Acceleration speed:</source>
-        <translation>Скорост на ускорение:</translation>
+        <translation>Ускорение:</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="60"/>
         <source>Tap to click</source>
-        <translation>Докоснете, за да щракнете</translation>
+        <translation>Докосване за кликване</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="67"/>
@@ -268,7 +268,7 @@ Mouse, touchpad and keyboard can be configured in the settings of the compositor
     <message>
         <location filename="../touchpadconfig.ui" line="74"/>
         <source>Tap and drag</source>
-        <translation>Чукнете и плъзнете</translation>
+        <translation>Докосване и влачене</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="86"/>
@@ -278,7 +278,7 @@ Mouse, touchpad and keyboard can be configured in the settings of the compositor
     <message>
         <location filename="../touchpadconfig.ui" line="109"/>
         <source>&amp;Disabled</source>
-        <translation>&amp;Изключен</translation>
+        <translation>&amp;Изключено</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="116"/>
@@ -288,20 +288,20 @@ Mouse, touchpad and keyboard can be configured in the settings of the compositor
     <message>
         <location filename="../touchpadconfig.ui" line="123"/>
         <source>Ed&amp;ge</source>
-        <translation>Ръб, край</translation>
+        <translation>По р&amp;ъба</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="130"/>
         <source>B&amp;utton</source>
-        <translation>б&amp;утон</translation>
+        <translation>Б&amp;утон</translation>
     </message>
     <message>
         <location filename="../touchpadconfig.ui" line="30"/>
         <source>DeviceInfoLabel</source>
-        <translation>Инфоетикет Устройство</translation>
+        <translation>DeviceInfoLabel</translation>
     </message>
     <message>
-        <location filename="../touchpadconfig.cpp" line="85"/>
+        <location filename="../touchpadconfig.cpp" line="94"/>
         <source>LXQt only supports &quot;libinput&quot; as xinput driver.
 (current value: %1)
 
