@@ -170,50 +170,52 @@
     <message>
         <location filename="../mouseconfig.cpp" line="65"/>
         <source>Use the settings of the Wayland compositor for more options about mouse, touchpad and keyboard.</source>
-        <translation type="unfinished"></translation>
+        <translation>Erabili Wayland konposatzailearen ezarpenak saguari, ukipen-panelari eta teklatuari buruzko aukera gehiago lortzeko.</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="39"/>
+        <location filename="../lxqt-config-input.cpp" line="41"/>
         <source>LXQt input settings are currently unsupported under Wayland.
 
 Mouse, touchpad and keyboard can be configured in the settings of the compositor.</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt sarrera ezarpenak ez dira onartzen Wayland-en une honetan.
+
+Sagua, ukipen-panela eta teklatua konposatzailearen ezarpenetan konfigura daitezke.</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="76"/>
+        <location filename="../lxqt-config-input.cpp" line="78"/>
         <source>Keyboard and Mouse Settings</source>
         <translation>Teklatuko eta saguaren ezarpenak</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="94"/>
+        <location filename="../lxqt-config-input.cpp" line="96"/>
         <source>Mouse</source>
         <translation>Saguaren</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="103"/>
+        <location filename="../lxqt-config-input.cpp" line="105"/>
         <source>Cursor</source>
         <translation>Kurtsorea</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="108"/>
+        <location filename="../lxqt-config-input.cpp" line="110"/>
         <source>To apply the changes also to GTK, check LXQt Appearance Configuration → GTK Style.</source>
-        <translation type="unfinished"></translation>
+        <translation>Aldaketak GTK-ri ere aplikatzeko, egiaztatu LXQt Itxura Konfigurazioa → GTK Estiloa.</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="112"/>
+        <location filename="../lxqt-config-input.cpp" line="114"/>
         <source>Keyboard</source>
         <translation>Teklatua</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="123"/>
+        <location filename="../lxqt-config-input.cpp" line="125"/>
         <source>Keyboard Layout</source>
         <translation>Teklatuaren Diseinua</translation>
     </message>
     <message>
-        <location filename="../lxqt-config-input.cpp" line="136"/>
+        <location filename="../lxqt-config-input.cpp" line="138"/>
         <source>Mouse and Touchpad</source>
         <translation>Sagua eta Touchpad</translation>
     </message>
@@ -299,7 +301,7 @@ Mouse, touchpad and keyboard can be configured in the settings of the compositor
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../touchpadconfig.cpp" line="85"/>
+        <location filename="../touchpadconfig.cpp" line="94"/>
         <source>LXQt only supports &quot;libinput&quot; as xinput driver.
 (current value: %1)
 
